@@ -27,8 +27,8 @@ from rasterio._err import CPLE_AppDefinedError
 import numpy as np
 from rio_tiler.errors import EmptyMosaicError
 from rio_tiler.models import ImageData
-from rio_tiler.io import COGReader
-from rio_tiler.mosaic import mosaic_reader
+from rio_tiler.io.cogeo import COGReader
+from rio_tiler.mosaic.reader import mosaic_reader
 
 from cog_worker.types import BoundingBox
 from cog_worker.utils import _bbox_size, _get_profile
@@ -217,9 +217,9 @@ class Worker:
             writer.write(arr)
             if isinstance(arr, np.ma.MaskedArray):
                 mask = np.ma.getmask(arr)
-                if len(arr.shape) == 3:
+                if len(mask.shape) == 3:
                     mask = np.any(mask, axis=0)
-                writer.write_mask(mask)
+                writer.write_mask(~mask)
 
     def clip_buffer(self, arr: np.ndarray) -> np.ndarray:
         """Clip the buffer pixels from an array if they exist.
@@ -265,7 +265,7 @@ def _read_COG(
 ) -> ImageData:
     """Read part of a COG, warping and resampling to a target shape."""
     tries = 0
-    while tries < 5:
+    while tries <= 10:
         try:
             with COGReader(filepath=asset, **kwargs) as cog:  # type: ignore
                 return cog.part(
@@ -280,4 +280,5 @@ def _read_COG(
             # Ignore some strange GDAL errors when reading in some projections
             # see: https://rasterio.groups.io/g/main/message/780
             logger.debug(e)
+        tries += 1
     raise Exception(f"Failed reading asset {asset}")
